pub async fn query(
prompt: impl Into<String>,
config: CodexConfig,
options: ThreadOptions,
) -> Result<Turn>Expand description
One-shot query: start a thread, run the prompt, return all events as a Turn.
pub async fn query(
prompt: impl Into<String>,
config: CodexConfig,
options: ThreadOptions,
) -> Result<Turn>One-shot query: start a thread, run the prompt, return all events as a Turn.