pub struct Thread { /* private fields */ }Expand description
A conversation thread with the Codex agent.
Each call to run() or run_streamed() spawns a codex exec subprocess.
Implementations
Sourceimpl Thread
impl Thread
Sourcepub fn with_approval_callback(self, callback: ApprovalCallback) -> Self
pub fn with_approval_callback(self, callback: ApprovalCallback) -> Self
Set an approval callback for handling permission requests.
Sourcepub fn with_patch_approval_callback(
self,
callback: PatchApprovalCallback,
) -> Self
pub fn with_patch_approval_callback( self, callback: PatchApprovalCallback, ) -> Self
Set a patch approval callback for handling file-patch approval requests.
Sourcepub fn with_event_callback(self, callback: EventCallback) -> Self
pub fn with_event_callback(self, callback: EventCallback) -> Self
Set an event callback for observing, transforming, or filtering events.
Sourcepub fn with_hooks(self, hooks: Vec<HookMatcher>) -> Self
pub fn with_hooks(self, hooks: Vec<HookMatcher>) -> Self
Add hooks to this thread.
Sourcepub fn with_transport(self, transport: Arc<dyn Transport>) -> Self
pub fn with_transport(self, transport: Arc<dyn Transport>) -> Self
Override the transport used for this thread (useful for testing).
When set, the provided transport is used instead of spawning a real
codex subprocess. The same connect / write / end_input / read_messages / close call sequence is used regardless.
Sourcepub async fn interrupt(&self) -> Result<()>
pub async fn interrupt(&self) -> Result<()>
Interrupt the currently running turn by sending SIGINT to the CLI subprocess.
Equivalent to pressing Ctrl-C. The CLI has close_timeout seconds to clean
up before being force-killed. Returns Ok(()) if no turn is in progress.
Sourcepub async fn run(
&mut self,
input: impl Into<Input>,
turn_options: TurnOptions,
) -> Result<Turn>
pub async fn run( &mut self, input: impl Into<Input>, turn_options: TurnOptions, ) -> Result<Turn>
Run a prompt and collect all events into a Turn.
Sourcepub async fn run_streamed(
&mut self,
input: impl Into<Input>,
turn_options: TurnOptions,
) -> Result<StreamedTurn>
pub async fn run_streamed( &mut self, input: impl Into<Input>, turn_options: TurnOptions, ) -> Result<StreamedTurn>
Run a prompt and return a streaming StreamedTurn.